# OSBot-AWS

![Current Release](https://img.shields.io/badge/release-v2.33.0-blue)

Large number of AWS apis and utils from the OWASP Security Bot (OSBot) which make
the use of AWS's boto3 library easier and more intuitive.

## Current version is 2.x.x 

This version has a number of breaking changes, mainly on the location of the apis, 
since we are moving into a specific folder per service (e.g. S3, SQS, etc)

### Install from PyPi

`pip3 install osbot-aws`

https://pypi.org/project/osbot-aws/

### Previous release

Previous stable release is v1.0.0 and is available at https://github.com/owasp-sbot/OSBot-AWS/releases/tag/v1.0.0
